//---------------------------------------------------------------------------
// Code to flash LED and turn on LEDs when switches are pressed

//---------------------------------------------------------------------------
// Header files

#include <p30f6014.h>             //Standard header file

//---------------------------------------------------------------------------
// Configuration bits

   _FOSC(CSW_FSCM_OFF & XT_PLL4);   //XT with 4xPLL oscillator, Failsafe clock off
   _FWDT(WDT_OFF);                  //Watchdog timer disabled
   _FBORPOR(PBOR_OFF & MCLR_EN);    //Brown-out reset disabled, MCLR reset enabled
   _FGS(CODE_PROT_OFF);             //Code protect disabled

//---------------------------------------------------------------------------
// Definitions

#define Fcy 7370000                 //7.37MHz oscillator with 4xPLL -> 7.37MIPs

//---------------------------------------------------------------------------
// Main routine
//---------------------------------------------------------------------------

int main(void)
{		
//------------------------------------------------------------------------------
//Initialize LED outputs on PORTD bits 0-3 and switch inputs on PORTA bits 12 - 15

	LATD = 0xFFFF;                //Turn off all LEDS
   TRISD = 0xFFF0;               //Set LED pins as outputs
   TRISA = 0xFFFF;               //Set pushbutton switch pins as inputs

//------------------------------------------------------------------------------
//Initialize Timer1 for 1/2 second period

   T1CON = 0;                    //Turn off Timer1 by clearing control register
	TMR1 = 0;                     //Start Timer1 at zero
	PR1 = (Fcy/256)/2;            //Set period register value for 1/2 second 
   T1CON = 0x8030;               //Configure Timer1 (timer on, continue in IDLE, not gated, 1:256 prescaler, internal clock)

//------------------------------------------------------------------------------
//Loop while flashing LED RD4 and testing switch inputs

   while (1)
   {
      if(IFS0bits.T1IF == 1)     //Check if Timer1 interrupt flag is set
	   {
      IFS0bits.T1IF = 0;         //Clear Timer1 interrupt flag
      LATDbits.LATD0 = !LATDbits.LATD0; //Toggle LED1 RD0
      }
      if(PORTAbits.RA12 == 0)    //Check if SW1 button is pressed
	   {
   	   LATDbits.LATD2 = 0;     //Turn LED3 RD2 on
		   LATDbits.LATD3 = 1;     //Turn LED4 RD3 off
      }
      if(PORTAbits.RA13 == 0)    //Check if SW2 button is pressed
      {
         LATDbits.LATD3 = 0;     //Turn LED4 RD3 on
         LATDbits.LATD2 = 1;     //Turn LED3 RD2 off
      }
	}
}

//---------------------------------------------------------------------------
